@@ -2,12 +2,11 @@ import numpy as np
 
 
 class BaseDimensionalityReduction:
-    """ The Base Dimensionality Reduction class
+    """The Base Dimensionality Reduction class.
 
     You can use this to skip over the dimensionality reduction step in BERTopic.
 
     Examples:
-
     This will skip over the reduction step in BERTopic:
 
     ```python
@@ -19,6 +18,7 @@ class BaseDimensionalityReduction:
     topic_model = BERTopic(umap_model=empty_reduction_model)
     ```
     """
+
     def fit(self, X: np.ndarray = None):
         return self
 
