@@ -4,6 +4,7 @@ from ._barchart import visualize_barchart
 from ._documents import visualize_documents
 from ._term_rank import visualize_term_rank
 from ._hierarchy import visualize_hierarchy
+from ._datamap import visualize_document_datamap
 from ._distribution import visualize_distribution
 from ._topics_over_time import visualize_topics_over_time
 from ._topics_per_class import visualize_topics_per_class
@@ -19,8 +20,9 @@ __all__ = [
     "visualize_term_rank",
     "visualize_hierarchy",
     "visualize_distribution",
+    "visualize_document_datamap",
     "visualize_topics_over_time",
     "visualize_topics_per_class",
     "visualize_hierarchical_documents",
-    "visualize_approximate_distribution"
+    "visualize_approximate_distribution",
 ]
