@@ -1,7 +1,4 @@
 from ._ctfidf import ClassTfidfTransformer
 from ._online_cv import OnlineCountVectorizer
 
-__all__ = [
-    "ClassTfidfTransformer",
-    "OnlineCountVectorizer"
-]
+__all__ = ["ClassTfidfTransformer", "OnlineCountVectorizer"]
