@@ -3,9 +3,9 @@ from bertopic import BERTopic
 
 def test_load_save_model():
     model = BERTopic(language="Dutch", embedding_model=None)
-    model.save("test")
+    model.save("test", serialization="pickle")
     loaded_model = BERTopic.load("test")
-    assert type(model) == type(loaded_model)
+    assert type(model) is type(loaded_model)
     assert model.language == loaded_model.language
     assert model.embedding_model == loaded_model.embedding_model
     assert model.top_n_words == loaded_model.top_n_words
@@ -19,4 +19,4 @@ def test_get_params():
     assert not params["nr_topics"]
     assert params["n_gram_range"] == (1, 1)
     assert params["min_topic_size"] == 10
-    assert params["language"] == 'english'
+    assert params["language"] == "english"
